pub struct LayerDef {Show 17 fields
pub tileset_def_uid: Option<i32>,
pub __type: String,
pub px_offset_y: i32,
pub auto_rule_groups: Vec<AutoLayerRuleGroup>,
pub auto_tileset_def_uid: Option<i32>,
pub uid: i32,
pub required_tags: Vec<String>,
pub excluded_tags: Vec<String>,
pub tile_pivot_y: f32,
pub layer_def_type: Value,
pub int_grid_values: Vec<IntGridValueDef>,
pub display_opacity: f32,
pub px_offset_x: i32,
pub auto_source_layer_def_uid: Option<i32>,
pub identifier: String,
pub grid_size: i32,
pub tile_pivot_x: f32,
}Expand description
Fields
tileset_def_uid: Option<i32>Reference to the Tileset UID being used by this Tile layer. WARNING: some layer instances might use a different tileset. So most of the time, you should probably use the __tilesetDefUid value from layer instances.
__type: StringType of the layer (IntGrid, Entities, Tiles or AutoLayer)
px_offset_y: i32Y offset of the layer, in pixels (IMPORTANT: this should be added to the LayerInstance optional offset)
auto_rule_groups: Vec<AutoLayerRuleGroup>Contains all the auto-layer rule definitions.
auto_tileset_def_uid: Option<i32>Reference to the Tileset UID being used by this auto-layer rules. WARNING: some layer instances might use a different tileset. So most of the time, you should probably use the __tilesetDefUid value from layer instances.
uid: i32Unique Int identifier
An array of tags to filter Entities that can be added to this layer
An array of tags to forbid some Entities in this layer
tile_pivot_y: f32If the tiles are smaller or larger than the layer grid, the pivot value will be used to position the tile relatively its grid cell.
layer_def_type: ValueType of the layer as Haxe Enum Possible values: IntGrid, Entities, Tiles, AutoLayer
int_grid_values: Vec<IntGridValueDef>An array that defines extra optional info for each IntGrid value. The array is sorted using value (ascending).
display_opacity: f32Opacity of the layer (0 to 1.0)
px_offset_x: i32X offset of the layer, in pixels (IMPORTANT: this should be added to the LayerInstance optional offset)
auto_source_layer_def_uid: Option<i32>identifier: StringUnique String identifier
grid_size: i32Width and height of the grid in pixels
tile_pivot_x: f32If the tiles are smaller or larger than the layer grid, the pivot value will be used to position the tile relatively its grid cell.